general_rotation — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# general_rotation

ElectronicBandStructure.general_rotation(angle, kpoints, sx, sy, sz, rotAxis=[0, 0, 1], store=True)

  Apply a rotation defined by an angle and an axis.

  Returning value: (Kpoints, sx,sy,sz), the rotated Kpoints and spin

    vectors (if not the case, they will be empty arrays).

  Arguments angle: the rotation angle, must be in degrees!

  rotAxis : a fixed Axis when applying the symmetry, usually it is from Gamma to another point). It doesn’t need to be normalized. The RotAxis can be: [x,y,z] : a cartesian vector in k-space. ‘x’: [1,0,0], a rotation in the yz plane. ‘y’: [0,1,0], a rotation in the zx plane. ‘z’: [0,0,1], a rotation in the xy plane